==> haskell-vector-instances-3.4-83-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-53EHZc0FhiNJovv6d1YwaE
key: vector-instances-3.4-53EHZc0FhiNJovv6d1YwaE
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: 2a82a8e9cc288fa9f5bc0b8fa30ce5a3
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-53EHZc0FhiNJovv6d1YwaE
depends:
    base-4.11.1.0 comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    keys-3.12.1-E9HyHZGW1uDHqqrQMr1igk
    pointed-5.0.1-1sf3AfP2ZMx7THuSr7acLe
    semigroupoids-5.3.1-2SQHf3CZG98Au9TQFLLEKz
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH=73ea1c02e78d1366c378f0246c151a40
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             keys-3.12.1-E9HyHZGW1uDHqqrQMr1igk=cc220a2a3b8e98aab5de0d2daaf35735
             pointed-5.0.1-1sf3AfP2ZMx7THuSr7acLe=b3d0b3f353e21f7a5cd71f9353bb8971
             semigroupoids-5.3.1-2SQHf3CZG98Au9TQFLLEKz=b059bed71d22c08cffafcb404ea289fd
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4-84-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-instances
version: 3.4
id: vector-instances-3.4-BQXEqihl1UEErlaGKxI5HB
key: vector-instances-3.4-BQXEqihl1UEErlaGKxI5HB
license: BSD-3-Clause
maintainer: ekmett@gmail.com
author: Edward Kmett
homepage: http://github.com/ekmett/vector-instances
synopsis: Orphan Instances for '\''Data.Vector'\''
category: Data, Data Structures
abi: b8272390e77f2a66dc5ce072f1b9e94b
exposed: True
exposed-modules:
    Data.Vector.Instances
import-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/vector-instances-3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/vector-instances-3.4
hs-libraries: HSvector-instances-3.4-BQXEqihl1UEErlaGKxI5HB
depends:
    base-4.11.1.0 comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    keys-3.12.1-4OEzf3vHq8nKpFvhcYyNO5
    pointed-5.0.1-JaHSrMuMoLEBDgzi2VTY2N
    semigroupoids-5.3.1-GftqxfO19MMH8grpvmvONx
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             comonad-5.0.4-3ZzpO59XP2v9ynT2g1eEnH=73ea1c02e78d1366c378f0246c151a40
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             keys-3.12.1-4OEzf3vHq8nKpFvhcYyNO5=4e134a80083aa7497ccbf594bcbb71c5
             pointed-5.0.1-JaHSrMuMoLEBDgzi2VTY2N=f9d68ed5e126e68e9d914e53e7e20735
             semigroupoids-5.3.1-GftqxfO19MMH8grpvmvONx=66c322814c5a6541c0713134ceca4e93
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
haddock-html: /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
